/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.sinfo.importitem;

import java.util.List;

import org.dive4elements.river.importer.common.AbstractKmLineImport;
import org.dive4elements.river.model.sinfo.FlowDepthColumn;
import org.dive4elements.river.model.sinfo.FlowDepthValue;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Imported flow depth value of a river station.
 *
 * @author Matthias Schäfer
 *
 */
public class FlowDepthKmLineImport extends AbstractKmLineImport<FlowDepthColumn, FlowDepthValue> {

    /***** FIELDS *****/

    /**
     * Flow depth in m
     */
    private final double depth;


    /***** CONSTRUCTOR *****/

    public FlowDepthKmLineImport(final Double km, final double depth) {
        super(km.doubleValue());
        this.depth = depth;
    }


    /***** METHODS *****/

    @Override
    protected FlowDepthValue queryValueItem(final Session session, final FlowDepthColumn parent) {
        final Query query = session.createQuery("FROM FlowDepthValue WHERE (FlowDepthColumn=:parent)"
                + " AND (station BETWEEN (:station-0.0001) AND (:station+0.0001))");
        query.setParameter("parent", parent);
        query.setParameter("station", this.station);
        final List rows = query.list();
        if (!rows.isEmpty())
            return (FlowDepthValue) rows.get(0);
        else
            return null;
    }


    @Override
    protected FlowDepthValue createValueItem(final FlowDepthColumn parent) {
        return new FlowDepthValue(parent, this.station, this.depth);
    }
}
